@@ -3,7 +3,6 @@ A module of classification schemes for choropleth mapping.
 """
 import numpy as np
 import scipy.stats as stats
-import scipy as sp
 import copy
 from sklearn.cluster import KMeans as KMEANS
 from warnings import warn as Warn
@@ -52,7 +51,7 @@ CLASSIFIERS = (
 )
 
 K = 5  # default number of classes in any map scheme with this as an argument
-SEEDRANGE = 1000000  # range for drawing random integers from for Natural Breaks
+SEEDRANGE = 1000000  # range for drawing random ints from for Natural Breaks
 
 
 FMT = "{:.2f}"
@@ -181,7 +180,7 @@ def head_tail_breaks(values, cuts):
     mean = np.mean(values)
     cuts.append(mean)
     if len(set(values)) > 1:
-        return head_tail_breaks(values[values >= mean], cuts)
+        return head_tail_breaks(values[values > mean], cuts)
     return cuts
 
 
@@ -1192,7 +1191,8 @@ class EqualInterval(MapClassifier):
         see class docstring
 
         """
-
+        if min(y) == max(y):
+            raise ValueError("Not enough unique values in array to form k classes.")
         self.k = k
         MapClassifier.__init__(self, y)
         self.name = "EqualInterval"
@@ -1590,6 +1590,8 @@ class MaximumBreaks(MapClassifier):
     """
 
     def __init__(self, y, k=5, mindiff=0):
+        if min(y) == max(y):
+            raise ValueError("Not enough unique values in array to form k classes.")
         self.k = k
         self.mindiff = mindiff
         MapClassifier.__init__(self, y)
@@ -1825,12 +1827,8 @@ class FisherJenksSampled(MapClassifier):
     counts  : array
               (k,1), the number of observations falling in each class
 
-    Examples
-    --------
-
-    (Turned off due to timing being different across hardware)
-
-
+    Notes
+    -----
     For theoretical details see :cite:`Rey_2016`.
 
     """
@@ -1842,6 +1840,7 @@ class FisherJenksSampled(MapClassifier):
         if (pct * n > 1000) and truncate:
             pct = 1000.0 / n
         ids = np.random.randint(0, n, int(n * pct))
+        y = np.asarray(y)
         yr = y[ids]
         yr[-1] = max(y)  # make sure we have the upper bound
         yr[0] = min(y)  # make sure we have the min
@@ -2026,6 +2025,7 @@ class JenksCaspallSampled(MapClassifier):
         if pct * n > 1000:
             pct = 1000.0 / n
         ids = np.random.randint(0, n, int(n * pct))
+        y = np.asarray(y)
         yr = y[ids]
         yr[0] = max(y)  # make sure we have the upper bound
         self.original_y = y
@@ -2112,6 +2112,8 @@ class JenksCaspallForced(MapClassifier):
     """
 
     def __init__(self, y, k=K):
+        if min(y) == max(y):
+            raise ValueError("Not enough unique values in array to form k classes.")
         self.k = k
         MapClassifier.__init__(self, y)
         self.name = "JenksCaspallForced"
@@ -2393,6 +2395,8 @@ class MaxP(MapClassifier):
     """
 
     def __init__(self, y, k=K, initial=1000):
+        if min(y) == max(y):
+            raise ValueError("Not enough unique values in array to form k classes.")
         self.k = k
         self.initial = initial
         MapClassifier.__init__(self, y)
